<?php

namespace App\Http\Controller;

use App\Http\Business\CameraTypesBusiness;
use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Utils\LuController;
use App\Http\Business\CamerasBusiness;
use App\Http\DBO\CamerasDbo;
use Luticate\Utils\LuMultipleDbo;

class CamerasController extends LuController {
    protected function getBusiness()
    {
        return new CamerasBusiness();
    }

    /**
     * Get all camera types
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @param string $query The filter query
     * @return LuMultipleDbo
     */
    public function getAllTypes($page = 0, $perPage = PHP_INT_MAX, $query = "")
    {
        return CameraTypesBusiness::getAll($page, $perPage, $query);
    }

    /**
     * Get all cameras, sorted by name
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @param string $query The filter query
     * @param $_user LuticateUsersDbo Injected parameter
     * @return LuMultipleDbo
     */
    public function getAll($_user, $page = 0, $perPage = PHP_INT_MAX, $query = "")
    {
        return CamerasBusiness::getAllLight($_user, $page, $perPage, $query);
    }

    /**
     * Get a camera
     * @param $camera_id int The camera id
     * @param $_user LuticateUsersDbo Injected parameter
     * @return CamerasDbo
     */
    public function get($_user, $camera_id)
    {
        return CamerasBusiness::getLight($_user, $camera_id);
    }

    /**
     * Add a new camera
     * @param CamerasDbo $camera The camera
     * @return int
     */
    public function add(CamerasDbo $camera)
    {
        return CamerasBusiness::add($camera);
    }

    /**
     * Edit an existing camera
     * @param CamerasDbo $camera The camera
     * @param $camera_id int The camera id
     * @return bool
     */
    public function edit(CamerasDbo $camera, $camera_id)
    {
        return CamerasBusiness::edit($camera, $camera_id);
    }

    /**
     * Delete an existing camera
     * @param $camera_id int The camera id
     * @return bool
     */
    public function del($camera_id)
    {
        return CamerasBusiness::deleteById($camera_id);
    }

    /**
     * Get an image from the camera
     * @param $camera_id int The camera id
     * @return mixed
     */
    public function getImage($camera_id)
    {
        return CamerasBusiness::getImage($camera_id);
    }
}